@@ -95,8 +95,8 @@ public class LzListTest extends TestCase {
 	 */
 	public void testUniq() throws Exception {
 		List list = Arrays.asList(new String[]{"BB", "A", "CCC", "BB"});
-		List uniq = new LzList(list).uniq().sortAsc().list();
-		assertTrue(uniq.toString().equals("[A, BB, CCC]"));
+		List uniq = new LzList(list).uniq().list();
+		assertTrue(uniq.toString().equals("[BB, A, CCC]"));
 	}
 
 	/**
